@@ -74,7 +74,7 @@ class TflAppMain(QtGui.QMainWindow):
         currentLoc = self.getCurrentPCode()
         self.dest = self.ui.lineEditHomePC.text()
         print "start: " + currentLoc +  "& dest:" + self.dest
-        finalUrl = PLANNER_URL_PART1 + currentLoc + PLANNER_URL_PART2 + dest + PLANNER_URL_PART3
+        finalUrl = PLANNER_URL_PART1 + currentLoc + PLANNER_URL_PART2 + self.dest + PLANNER_URL_PART3
         QtGui.QDesktopServices.openUrl(QtCore.QUrl(finalUrl, QtCore.QUrl.TolerantMode))
 
     def getCurrentPCode(self):
